@@ -233,7 +233,7 @@ class Mark(Widget):
                                      name)
             else:
                 # Check scale range type compatibility
-                if scales[name].rtype != trait.get_metadata('rtype'):
+                if scales[name].rtype != trait.metadata['rtype']:
                     raise TraitError("Range type mismatch for scale %s." %
                                      name)
         return scales
@@ -323,8 +323,7 @@ class Lines(Mark):
         Interpolation scheme used for interpolation between the data points
         provided. Please refer to the svg interpolate documentation for details
         about the different interpolation schemes.
-    marker: {'circle', 'cross', 'diamond', 'square', 'triangle-down',
-             'triangle-up', 'arrow', 'rectangle', 'ellipse'}
+    marker: {'circle', 'cross', 'diamond', 'square', 'triangle-down', 'triangle-up', 'arrow', 'rectangle', 'ellipse'}
         Marker shape
     marker_size: nonnegative int (default: 64)
         Default marker size in pixels
@@ -580,14 +579,15 @@ class Scatter(_ScatterBase):
         Font-awesome icon for that mark
     name: string (class-level attribute)
         User-friendly name of the mark
-    marker: {'circle', 'cross', 'diamond', 'square', 'triangle-down',
-             'triangle-up', 'arrow', 'rectangle', 'ellipse'}
+    marker: {'circle', 'cross', 'diamond', 'square', 'triangle-down', 'triangle-up', 'arrow', 'rectangle', 'ellipse'}
         Marker shape
     colors: list of colors (default: ['steelblue'])
         List of colors of the markers. If the list is shorter than the number
         of points, the colors are reused.
     default_colors: Deprecated
         Same as `colors`, deprecated as of version 0.8.4
+    fill: Bool (default: True)
+        Whether to fill the markers or not
     stroke: Color or None (default: None)
         Stroke color of the marker
     stroke_width: Float (default: 1.5)
@@ -818,7 +818,7 @@ class Hist(Mark):
         Boolean attribute to return normalized values which
         sum to 1 or direct counts for the `count` attribute. The scale of
         `count` attribute is determined by the value of this flag.
-    colors: list of colors (default: CATEGORY10)
+    colors: list of colors (default: ['steelblue'])
         List of colors of the Histogram. If the list is shorter than the number
         of bins, the colors are reused.
     stroke: Color or None (default: None)
@@ -874,7 +874,7 @@ class Hist(Mark):
     midpoints = List(read_only=True).tag(sync=True, display_name='Mid points')
     # midpoints is a read-only attribute that is set when the mark is drawn
     colors = List(trait=Color(default_value=None, allow_none=True),
-                  default_value=CATEGORY10)\
+                  default_value=['steelblue'])\
         .tag(sync=True, display_name='Colors')
     stroke = Color(None, allow_none=True).tag(sync=True)
     opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True))\
@@ -981,10 +981,14 @@ class Bars(Mark):
         Specifies whether the bar chart is drawn horizontally or vertically.
         If a horizontal bar chart is drawn, the x data is drawn vertically.
     padding: float (default: 0.05)
-        attribute to control the spacing between the bars value is specified
+        Attribute to control the spacing between the bars value is specified
         as a percentage of the width of the bar
+    fill: Bool (default: True)
+        Whether to fill the bars or not
     stroke: Color or None (default: None)
-        stroke color for the bars
+        Stroke color for the bars
+    stroke_width: Float (default: 0.)
+        Stroke width of the bars
     opacities: list of floats (default: [])
         Opacities for the bars. Defaults to 1 when the list is too
         short, or the element of the list is set to None.
@@ -992,6 +996,16 @@ class Bars(Mark):
         reference value from which the bars are drawn. defaults to 0.0
     align: {'center', 'left', 'right'}
         alignment of bars with respect to the tick value
+    label_display: bool (default: False)
+        whether or not to display bar data labels
+    label_display_format: string (default: .2f)
+        format for displaying values.
+    label_font_style: dict
+        CSS style for the text of each cell
+    label_display_vertical_offset: float
+        vertical offset value for the label display
+    label_display_horizontal_offset: float
+        horizontal offset value for the label display
 
     Data Attributes
 
@@ -1028,6 +1042,17 @@ class Bars(Mark):
              atype='bqplot.ColorAxis', **array_serialization)\
         .valid(array_squeeze, array_dimension_bounds(1, 1))
 
+    # Bar text labels attributes -- add default values.
+    # Add bool for displaying a label or not. Add d3 formatting in docstring
+    label_display = Bool(default_value=False).tag(sync=True)
+    label_display_format = Unicode(default_value=".2f",
+                                   allow_none=False).tag(sync=True)
+    label_font_style = Dict().tag(sync=True)
+    label_display_vertical_offset = Float(default_value=0.0,
+                                          allow_none=False).tag(sync=True)
+    label_display_horizontal_offset = Float(default_value=0.0,
+                                            allow_none=False).tag(sync=True)
+
     # Other attributes
     scales_metadata = Dict({
         'x': {'orientation': 'horizontal', 'dimension': 'x'},
@@ -1043,7 +1068,9 @@ class Bars(Mark):
                   default_value=['steelblue'])\
         .tag(sync=True, display_name='Colors')
     padding = Float(0.05).tag(sync=True)
+    fill = Bool(True).tag(sync=True)
     stroke = Color(None, allow_none=True).tag(sync=True)
+    stroke_width = Float(1.).tag(sync=True, display_name='Stroke width')
     base = Float().tag(sync=True)
     opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True))\
         .tag(sync=True, display_name='Opacities')
@@ -1750,6 +1777,7 @@ class Image(Mark):
     _view_name = Unicode('Image').tag(sync=True)
     _model_name = Unicode('ImageModel').tag(sync=True)
     image = Instance(widgets.Image).tag(sync=True, **widget_serialization)
+    pixelated = Bool(True).tag(sync=True)
     x = Array(default_value=(0, 1)).tag(sync=True, scaled=True,
                                         rtype='Number',
                                         atype='bqplot.Axis',
